# Roadmap

## Milestones

- ✅ **v1.0 Junction Fix** — Phases 1-3 (shipped 2026-03-19) → [archive](milestones/v1.0-ROADMAP.md)
- ✅ **v1.2 Performance** — Phases 1-4 (shipped 2026-03-20) → [archive](milestones/v1.2-ROADMAP.md)
